@@ -107,9 +107,6 @@ FAILEDOPERATION_PUBLISHLAYERVERSION = 'FailedOperation.PublishLayerVersion'
 # 当前函数状态无法发布版本，请在状态为正常时发布。
 FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 
-# 角色不存在。
-FAILEDOPERATION_QCSROLENOTFOUND = 'FailedOperation.QcsRoleNotFound'
-
 # 当前函数已有保留并发设置任务处于进行中，请稍后重试。
 FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 
@@ -176,6 +173,9 @@ INVALIDPARAMETERVALUE_ACTION = 'InvalidParameterValue.Action'
 # AdditionalVersionWeights参数传入错误。
 INVALIDPARAMETERVALUE_ADDITIONALVERSIONWEIGHTS = 'InvalidParameterValue.AdditionalVersionWeights'
 
+# 不支持删除默认别名，请修正后重试。
+INVALIDPARAMETERVALUE_ALIAS = 'InvalidParameterValue.Alias'
+
 # ApiGateway参数错误。
 INVALIDPARAMETERVALUE_APIGATEWAY = 'InvalidParameterValue.ApiGateway'
 
@@ -191,9 +191,6 @@ INVALIDPARAMETERVALUE_CFSPARAMETERDUPLICATE = 'InvalidParameterValue.CfsParamete
 # cfs配置项取值与规范不符。
 INVALIDPARAMETERVALUE_CFSPARAMETERERROR = 'InvalidParameterValue.CfsParameterError'
 
-# cfs参数格式与规范不符。
-INVALIDPARAMETERVALUE_CFSSTRUCTIONERROR = 'InvalidParameterValue.CfsStructionError'
-
 # Ckafka传入错误。
 INVALIDPARAMETERVALUE_CKAFKA = 'InvalidParameterValue.Ckafka'
 
@@ -353,6 +350,9 @@ INVALIDPARAMETERVALUE_RUNTIME = 'InvalidParameterValue.Runtime'
 # searchkey 不是 Keyword,Tag 或者 Runtime。
 INVALIDPARAMETERVALUE_SEARCHKEY = 'InvalidParameterValue.SearchKey'
 
+# SecretInfo错误。
+INVALIDPARAMETERVALUE_SECRETINFO = 'InvalidParameterValue.SecretInfo'
+
 # ServiceName命名不规范。
 INVALIDPARAMETERVALUE_SERVICENAME = 'InvalidParameterValue.ServiceName'
 
@@ -479,9 +479,6 @@ RESOURCEINUSE_CMQ = 'ResourceInUse.Cmq'
 # Cos已被占用。
 RESOURCEINUSE_COS = 'ResourceInUse.Cos'
 
-# 函数已存在。
-RESOURCEINUSE_FUNCTION = 'ResourceInUse.Function'
-
 # FunctionName已存在。
 RESOURCEINUSE_FUNCTIONNAME = 'ResourceInUse.FunctionName'
 
@@ -512,6 +509,9 @@ RESOURCENOTFOUND_ASYNCEVENT = 'ResourceNotFound.AsyncEvent'
 # Cdn不存在。
 RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 
+# 指定的cfs下未找到您所指定的挂载点。
+RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
+
 # cfs与云函数所处vpc不一致。
 RESOURCENOTFOUND_CFSVPCNOTMATCH = 'ResourceNotFound.CfsVpcNotMatch'
 
